-- Skrypt: usageMachine
-- Wersja: 1.0
--20.01.2010
-- Autor: hannibal5, na podstawie skryptu napisanego przez Face

---LOG---
-------------------------------------
--Wersja: 1.0 (20.01.2010)
-----Symulacja postarzania maszyny przez zmiane tekstury
-------------------------------------

usageMachine = {};
------------------------------------------------------------------------------------------------------------------------------------
function usageMachine.prerequisitesPresent(specializations)

    return true;
	
end;
------------------------------------------------------------------------------------------------------------------------------------
function usageMachine:load(xmlFile)

	self.machineInUse = SpecializationUtil.callSpecializationsFunction("machineInUse"); --Funkcja odlicza czas wykorzystania maszyny i dokonuje obliczen dla shadera
	
	local count = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.usage#count"), 0); --Liczba komponentow dla ktorych bedzie nastepowala zmiana tekstury
	self.usageComponents = {}; --Tablica przechowujaca dane o poszczegolnych komponentach
	if count ~= 0 then
		for i = 1, count do
			local componentName = string.format("vehicle.usage.usageComponent%d", i);
			self.usageComponents[i] = {}; --Tablica z danymi dla konkretnego komponentu
			self.usageComponents[i].ground = Utils.getNoNil(getXMLBool(xmlFile, componentName .. "#ground"), false); --Okresla czy komponent musi miec kontak z ziemia aby zmienic teksture
			self.usageComponents[i].index = Utils.indexToObject(self.components, getXMLString(xmlFile, componentName .. "#index")); --Identyfikator komponentu
			self.usageComponents[i].usageTime = Utils.getNoNil(getXMLFloat(xmlFile, componentName .. "#usageTime"), 1) * 60 * 60 * 1000; --Czas po ktorym nastepuje calkowita zmiana tekstury (domyslnie 1 godz.)
			self.usageComponents[i].usageScale = 0; --Aktualna przezroczystosc nowej tekstury
			self.usageComponents[i].oldUsageScale = self.usageComponents[i].usageScale --Przezroczystosc nowej tekstury przed aktualizacja wartosci
		end;
	end;
	
	self.changeUsageScale = false; --Wskaznik, okresla czy ma nastapic zmiana wartosci przezroczystosci nowej tekstury
	
end;
------------------------------------------------------------------------------------------------------------------------------------
function usageMachine:delete()

end;
------------------------------------------------------------------------------------------------------------------------------------
function usageMachine:mouseEvent(posX, posY, isDown, isUp, button)

end;
------------------------------------------------------------------------------------------------------------------------------------
function usageMachine:keyEvent(unicode, sym, modifier, isDown)

end;
------------------------------------------------------------------------------------------------------------------------------------
function usageMachine:update(dt)

	if self:getIsActive() then
		self:machineInUse(dt);
	end;
	
	for i = 1, table.getn(self.usageComponents) do
		if math.abs(self.usageComponents[i].usageScale - self.usageComponents[i].oldUsageScale) > 0.001 then --Jezeli nastapila zmiana wartosci przezroczystosci
			setShaderParameter(self.usageComponents[i].index, "usageScale", self.usageComponents[i].usageScale, 0, 0, 0, false); --Przypisanie nowej wartosci dla shadera
			self.usageComponents[i].oldUsageScale = self.usageComponents[i].usageScale;
		end;
	end;
	
	
end;
------------------------------------------------------------------------------------------------------------------------------------
function usageMachine:draw()

end;
------------------------------------------------------------------------------------------------------------------------------------
function usageMachine:machineInUse(dt)

	for i = 1, table.getn(self.usageComponents) do
		if self.usageComponents[i].usageScale > 1 then
			self.usageComponents[i].usageScale = 1;
		end;

		if self.usageComponents[i].usageScale < 1 then
			if not self.usageComponents[i].ground then
				self.changeUsageScale = true;
			elseif self.workActive then
				self.changeUsageScale = true;
			end;
			
			if self.changeUsageScale then --Zmiana wartosci dla ustawienia przezroczystosci nowej tekstury
				local scale = Utils.getMovedLimitedValues({self.usageComponents[i].usageScale}, {1}, {0}, 1, self.usageComponents[i].usageTime, dt, false);
				self.usageComponents[i].usageScale = scale[1];
				
				self.changeUsageScale = false;
			end;
		end;
	end;
	
end;
------------------------------------------------------------------------------------------------------------------------------------
function usageMachine:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)

	if not resetVehicles then
		for i = 1, table.getn(self.usageComponents) do
			local usageCompKey = key.. ".usageScale"..i;
			self.usageComponents[i].usageScale = Utils.getNoNil(getXMLFloat(xmlFile, usageCompKey.."#scale"), 0);
		end;
	end; 
	
    return BaseMission.VEHICLE_LOAD_OK;
	
end;
------------------------------------------------------------------------------------------------------------------------------------
function usageMachine:getSaveAttributesAndNodes(nodeIdent)	

	local usageAttributes = "";
    for i = 1, table.getn(self.usageComponents) do
		if i > 1 then
			usageAttributes = usageAttributes.."\n";
		end;
		usageAttributes = usageAttributes.. nodeIdent..'<usageScale'..i..' scale="'..tostring(self.usageComponents[i].usageScale)..'" />';
    end;
	
    return nil, usageAttributes;
	
end;
------------------------------------------------------------------------------------------------------------------------------------